to_local_anomaly_score — skchange

Skip to main content
`Ctrl`+`K`

# to_local_anomaly_score

to_local_anomaly_score(scorer: BaseCost | BaseLocalAnomalyScore) → BaseLocalAnomalyScore

  Convert compatible scorers to a saving.

  Parameters:
    scorerBaseCost or BaseLocalAnomalyScore

      The scorer to convert to a local anomaly score. If a local anomaly score is provided, it is returned as is.

  Returns:
    local_anomaly_scoreBaseLocalAnomalyScore

      The local anomaly score based on the cost function.